/*
 * LALVCSInfo.h.in - LAL VCS Information Header
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 *
 * Copyright (C) 2009,2010 Adam Mercer
 */

#ifndef _LALVCSINFO_H
#define _LALVCSINFO_H

/* remove SWIG interface directives */
#if !defined(SWIG) && !defined(SWIGLAL_STRUCT)
#define SWIGLAL_STRUCT(...)
#endif

#include <lal/LALConfig.h>

#ifdef __cplusplus
extern "C" {
#endif

/* vcs information defines */
#define LAL_NAME "LAL"
#define LAL_VCS_ID "0bcd95daf135161d117d52234e6272297a12894a"
#define LAL_VCS_DATE "2011-12-13 18:43:36 +0000"
#define LAL_VCS_BRANCH "None"
#define LAL_VCS_TAG "lal-v6.6.0"
#define LAL_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
#define LAL_VCS_COMMITTER "Adam Mercer <adam.mercer@ligo.org>"
#define LAL_VCS_STATUS "CLEAN: All modifications committed"

/* vcs information defines - identable*/
#define LAL_VCS_IDENT_ID "$" "LALId: 0bcd95daf135161d117d52234e6272297a12894a " "$"
#define LAL_VCS_IDENT_DATE "$" "LALDate: 2011-12-13 18:43:36 +0000 " "$"
#define LAL_VCS_IDENT_BRANCH "$" "LALBranch: None " "$"
#define LAL_VCS_IDENT_TAG "$" "LALTag: lal-v6.6.0 " "$"
#define LAL_VCS_IDENT_AUTHOR "$" "LALAuthor: Adam Mercer <adam.mercer@ligo.org> " "$"
#define LAL_VCS_IDENT_COMMITTER "$" "LALCommitter: Adam Mercer <adam.mercer@ligo.org> " "$"
#define LAL_VCS_IDENT_STATUS "$" "LALStatus: CLEAN: All modifications committed " "$"

/* global variables for vcs information, defined in LALVCSInfo.c */
extern const char *const lalVCSVersion;
extern const char *const lalVCSId;
extern const char *const lalVCSDate;
extern const char *const lalVCSBranch;
extern const char *const lalVCSTag;
extern const char *const lalVCSAuthor;
extern const char *const lalVCSCommitter;
extern const char *const lalVCSStatus;

/* define vcs information structure */
#ifdef SWIG /* SWIG interface directives */
%warnfilter(SWIGWARN_TYPEMAP_CHARLEAK) tagLALVCSInfo;
#endif /* SWIG */
typedef struct tagLALVCSInfo
{
  SWIGLAL_STRUCT(LALVCSInfo);
  const char *name;
  const char *version;
  const char *vcsId;
  const char *vcsDate;
  const char *vcsBranch;
  const char *vcsTag;
  const char *vcsAuthor;
  const char *vcsCommitter;
  const char *vcsStatus;
} LALVCSInfo;

/* header and library vcs information structures */
extern struct tagLALVCSInfo lalVCSInfo;
static const struct tagLALVCSInfo lalHeaderVCSInfo = { \
  LAL_NAME, \
  LAL_VERSION, \
  LAL_VCS_ID, \
  LAL_VCS_DATE, \
  LAL_VCS_BRANCH, \
  LAL_VCS_TAG, \
  LAL_VCS_AUTHOR, \
  LAL_VCS_COMMITTER, \
  LAL_VCS_STATUS \
};

/*
 * function prototypes
 */

/* function to compare two LALVCSInfo structures */
int XLALVCSInfoCompare(const LALVCSInfo *header, const LALVCSInfo *library);

#ifdef __cplusplus
}
#endif

#endif /* _LALVCSINFO_H */

/*
 * vim: tw=0 ts=2 et
 */
